# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: demoparser/protobufs/econ_gcmessages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from demoparser.protobufs import steammessages_pb2 as demoparser_dot_protobufs_dot_steammessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='demoparser/protobufs/econ_gcmessages.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n*demoparser/protobufs/econ_gcmessages.proto\x1a(demoparser/protobufs/steammessages.proto\"\x98\x01\n\x11\x43MsgGCGiftedItems\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x14\n\x0cgiftdefindex\x18\x02 \x01(\r\x12\x1a\n\x12max_gifts_possible\x18\x03 \x01(\r\x12\x1f\n\x17num_eligible_recipients\x18\x04 \x01(\r\x12\x1d\n\x15recipients_accountids\x18\x05 \x03(\r\"E\n\x12\x43MsgApplyAutograph\x12\x19\n\x11\x61utograph_item_id\x18\x01 \x01(\x04\x12\x14\n\x0citem_item_id\x18\x02 \x01(\x04\"7\n&CMsgGCUserTrackTimePlayedConsecutively\x12\r\n\x05state\x18\x01 \x01(\r*\x83&\n\nEGCItemMsg\x12\x11\n\x0ck_EMsgGCBase\x10\xe8\x07\x12\x1c\n\x17k_EMsgGCSetItemPosition\x10\xe9\x07\x12\x12\n\rk_EMsgGCCraft\x10\xea\x07\x12\x1a\n\x15k_EMsgGCCraftResponse\x10\xeb\x07\x12\x13\n\x0ek_EMsgGCDelete\x10\xec\x07\x12$\n\x1fk_EMsgGCVerifyCacheSubscription\x10\xed\x07\x12\x15\n\x10k_EMsgGCNameItem\x10\xee\x07\x12\x18\n\x13k_EMsgGCUnlockCrate\x10\xef\x07\x12 \n\x1bk_EMsgGCUnlockCrateResponse\x10\xf0\x07\x12\x16\n\x11k_EMsgGCPaintItem\x10\xf1\x07\x12\x1e\n\x19k_EMsgGCPaintItemResponse\x10\xf2\x07\x12\"\n\x1dk_EMsgGCGoldenWrenchBroadcast\x10\xf3\x07\x12\x18\n\x13k_EMsgGCMOTDRequest\x10\xf4\x07\x12 \n\x1bk_EMsgGCMOTDRequestResponse\x10\xf5\x07\x12\'\n\"k_EMsgGCAddItemToSocket_DEPRECATED\x10\xf6\x07\x12/\n*k_EMsgGCAddItemToSocketResponse_DEPRECATED\x10\xf7\x07\x12+\n&k_EMsgGCAddSocketToBaseItem_DEPRECATED\x10\xf8\x07\x12\'\n\"k_EMsgGCAddSocketToItem_DEPRECATED\x10\xf9\x07\x12/\n*k_EMsgGCAddSocketToItemResponse_DEPRECATED\x10\xfa\x07\x12\x19\n\x14k_EMsgGCNameBaseItem\x10\xfb\x07\x12!\n\x1ck_EMsgGCNameBaseItemResponse\x10\xfc\x07\x12(\n#k_EMsgGCRemoveSocketItem_DEPRECATED\x10\xfd\x07\x12\x30\n+k_EMsgGCRemoveSocketItemResponse_DEPRECATED\x10\xfe\x07\x12!\n\x1ck_EMsgGCCustomizeItemTexture\x10\xff\x07\x12)\n$k_EMsgGCCustomizeItemTextureResponse\x10\x80\x08\x12\x1b\n\x16k_EMsgGCUseItemRequest\x10\x81\x08\x12\x1c\n\x17k_EMsgGCUseItemResponse\x10\x82\x08\x12#\n\x1ek_EMsgGCGiftedItems_DEPRECATED\x10\x83\x08\x12\x1b\n\x16k_EMsgGCRemoveItemName\x10\x86\x08\x12\x1c\n\x17k_EMsgGCRemoveItemPaint\x10\x87\x08\x12\x19\n\x14k_EMsgGCGiftWrapItem\x10\x88\x08\x12!\n\x1ck_EMsgGCGiftWrapItemResponse\x10\x89\x08\x12\x18\n\x13k_EMsgGCDeliverGift\x10\x8a\x08\x12%\n k_EMsgGCDeliverGiftResponseGiver\x10\x8b\x08\x12(\n#k_EMsgGCDeliverGiftResponseReceiver\x10\x8c\x08\x12\x1e\n\x19k_EMsgGCUnwrapGiftRequest\x10\x8d\x08\x12\x1f\n\x1ak_EMsgGCUnwrapGiftResponse\x10\x8e\x08\x12\x19\n\x14k_EMsgGCSetItemStyle\x10\x8f\x08\x12\x1e\n\x19k_EMsgGCUsedClaimCodeItem\x10\x90\x08\x12\x16\n\x11k_EMsgGCSortItems\x10\x91\x08\x12*\n%k_EMsgGC_RevolvingLootList_DEPRECATED\x10\x92\x08\x12\x1a\n\x15k_EMsgGCLookupAccount\x10\x93\x08\x12\"\n\x1dk_EMsgGCLookupAccountResponse\x10\x94\x08\x12\x1e\n\x19k_EMsgGCLookupAccountName\x10\x95\x08\x12&\n!k_EMsgGCLookupAccountNameResponse\x10\x96\x08\x12\x1d\n\x18k_EMsgGCUpdateItemSchema\x10\x99\x08\x12 \n\x1bk_EMsgGCRemoveCustomTexture\x10\x9b\x08\x12(\n#k_EMsgGCRemoveCustomTextureResponse\x10\x9c\x08\x12\x1d\n\x18k_EMsgGCRemoveMakersMark\x10\x9d\x08\x12%\n k_EMsgGCRemoveMakersMarkResponse\x10\x9e\x08\x12#\n\x1ek_EMsgGCRemoveUniqueCraftIndex\x10\x9f\x08\x12+\n&k_EMsgGCRemoveUniqueCraftIndexResponse\x10\xa0\x08\x12\x1b\n\x16k_EMsgGCSaxxyBroadcast\x10\xa1\x08\x12!\n\x1ck_EMsgGCBackpackSortFinished\x10\xa2\x08\x12$\n\x1fk_EMsgGCAdjustItemEquippedState\x10\xa3\x08\x12\x18\n\x13k_EMsgGCCollectItem\x10\xa5\x08\x12)\n$k_EMsgGCItemAcknowledged__DEPRECATED\x10\xa6\x08\x12\x19\n\x14k_EMsgGC_ReportAbuse\x10\xa9\x08\x12!\n\x1ck_EMsgGC_ReportAbuseResponse\x10\xaa\x08\x12!\n\x1ck_EMsgGCNameItemNotification\x10\xac\x08\x12#\n\x1ek_EMsgGCApplyConsumableEffects\x10\xad\x08\x12 \n\x1bk_EMsgGCConsumableExhausted\x10\xae\x08\x12\x1e\n\x19k_EMsgGCShowItemsPickedUp\x10\xaf\x08\x12&\n!k_EMsgGCClientDisplayNotification\x10\xb0\x08\x12\x1d\n\x18k_EMsgGCApplyStrangePart\x10\xb1\x08\x12)\n$k_EMsgGC_IncrementKillCountAttribute\x10\xb2\x08\x12(\n#k_EMsgGC_IncrementKillCountResponse\x10\xb3\x08\x12 \n\x1bk_EMsgGCApplyPennantUpgrade\x10\xb4\x08\x12\x1d\n\x18k_EMsgGCSetItemPositions\x10\xb5\x08\x12\x1c\n\x17k_EMsgGCApplyEggEssence\x10\xb6\x08\x12#\n\x1ek_EMsgGCNameEggEssenceResponse\x10\xb7\x08\x12\x19\n\x14k_EMsgGCPaintKitItem\x10\xb8\x08\x12\x1d\n\x18k_EMsgGCPaintKitBaseItem\x10\xb9\x08\x12!\n\x1ck_EMsgGCPaintKitItemResponse\x10\xba\x08\x12\x18\n\x13k_EMsgGCGiftedItems\x10\xbb\x08\x12\x1c\n\x17k_EMsgGCUnlockItemStyle\x10\xbc\x08\x12$\n\x1fk_EMsgGCUnlockItemStyleResponse\x10\xbd\x08\x12\x19\n\x14k_EMsgGCApplySticker\x10\xbe\x08\x12\x1d\n\x18k_EMsgGCItemAcknowledged\x10\xbf\x08\x12\x19\n\x14k_EMsgGCStatTrakSwap\x10\xc0\x08\x12-\n(k_EMsgGCUserTrackTimePlayedConsecutively\x10\xc1\x08\x12\x18\n\x13k_EMsgGCTradingBase\x10\xdc\x0b\x12)\n$k_EMsgGCTrading_InitiateTradeRequest\x10\xdd\x0b\x12*\n%k_EMsgGCTrading_InitiateTradeResponse\x10\xde\x0b\x12!\n\x1ck_EMsgGCTrading_StartSession\x10\xdf\x0b\x12\x1c\n\x17k_EMsgGCTrading_SetItem\x10\xe0\x0b\x12\x1f\n\x1ak_EMsgGCTrading_RemoveItem\x10\xe1\x0b\x12$\n\x1fk_EMsgGCTrading_UpdateTradeInfo\x10\xe2\x0b\x12!\n\x1ck_EMsgGCTrading_SetReadiness\x10\xe3\x0b\x12&\n!k_EMsgGCTrading_ReadinessResponse\x10\xe4\x0b\x12\"\n\x1dk_EMsgGCTrading_SessionClosed\x10\xe5\x0b\x12\"\n\x1dk_EMsgGCTrading_CancelSession\x10\xe6\x0b\x12!\n\x1ck_EMsgGCTrading_TradeChatMsg\x10\xe7\x0b\x12!\n\x1ck_EMsgGCTrading_ConfirmOffer\x10\xe8\x0b\x12\'\n\"k_EMsgGCTrading_TradeTypingChatMsg\x10\xe9\x0b\x12)\n$k_EMsgGCServerBrowser_FavoriteServer\x10\xc1\x0c\x12*\n%k_EMsgGCServerBrowser_BlacklistServer\x10\xc2\x0c\x12\x1e\n\x19k_EMsgGCServerRentalsBase\x10\xa4\r\x12#\n\x1ek_EMsgGCItemPreviewCheckStatus\x10\xa5\r\x12&\n!k_EMsgGCItemPreviewStatusResponse\x10\xa6\r\x12\x1f\n\x1ak_EMsgGCItemPreviewRequest\x10\xa7\r\x12\'\n\"k_EMsgGCItemPreviewRequestResponse\x10\xa8\r\x12\x1e\n\x19k_EMsgGCItemPreviewExpire\x10\xa9\r\x12*\n%k_EMsgGCItemPreviewExpireNotification\x10\xaa\r\x12.\n)k_EMsgGCItemPreviewItemBoughtNotification\x10\xab\r\x12\x1f\n\x1ak_EMsgGCDev_NewItemRequest\x10\xd1\x0f\x12\'\n\"k_EMsgGCDev_NewItemRequestResponse\x10\xd2\x0f\x12!\n\x1ck_EMsgGCDev_PaintKitDropItem\x10\xd3\x0f\x12\x1d\n\x18k_EMsgGCStoreGetUserData\x10\xc4\x13\x12%\n k_EMsgGCStoreGetUserDataResponse\x10\xc5\x13\x12)\n$k_EMsgGCStorePurchaseInit_DEPRECATED\x10\xc6\x13\x12\x31\n,k_EMsgGCStorePurchaseInitResponse_DEPRECATED\x10\xc7\x13\x12\"\n\x1dk_EMsgGCStorePurchaseFinalize\x10\xc8\x13\x12*\n%k_EMsgGCStorePurchaseFinalizeResponse\x10\xc9\x13\x12 \n\x1bk_EMsgGCStorePurchaseCancel\x10\xca\x13\x12(\n#k_EMsgGCStorePurchaseCancelResponse\x10\xcb\x13\x12\"\n\x1dk_EMsgGCStorePurchaseQueryTxn\x10\xcc\x13\x12*\n%k_EMsgGCStorePurchaseQueryTxnResponse\x10\xcd\x13\x12\x1e\n\x19k_EMsgGCStorePurchaseInit\x10\xce\x13\x12&\n!k_EMsgGCStorePurchaseInitResponse\x10\xcf\x13\x12\"\n\x1dk_EMsgGCBannedWordListRequest\x10\xd0\x13\x12#\n\x1ek_EMsgGCBannedWordListResponse\x10\xd1\x13\x12(\n#k_EMsgGCToGCBannedWordListBroadcast\x10\xd2\x13\x12&\n!k_EMsgGCToGCBannedWordListUpdated\x10\xd3\x13\x12\x1e\n\x19k_EMsgGCToGCDirtySDOCache\x10\xd4\x13\x12&\n!k_EMsgGCToGCDirtyMultipleSDOCache\x10\xd5\x13\x12\"\n\x1dk_EMsgGCToGCUpdateSQLKeyValue\x10\xd6\x13\x12 \n\x1bk_EMsgGCToGCIsTrustedServer\x10\xd7\x13\x12(\n#k_EMsgGCToGCIsTrustedServerResponse\x10\xd8\x13\x12(\n#k_EMsgGCToGCBroadcastConsoleCommand\x10\xd9\x13\x12!\n\x1ck_EMsgGCServerVersionUpdated\x10\xda\x13\x12\x1b\n\x16k_EMsgGCApplyAutograph\x10\xdb\x13\x12%\n k_EMsgGCToGCWebAPIAccountChanged\x10\xdc\x13\x12!\n\x1ck_EMsgGCRequestAnnouncements\x10\xdd\x13\x12)\n$k_EMsgGCRequestAnnouncementsResponse\x10\xde\x13\x12%\n k_EMsgGCRequestPassportItemGrant\x10\xdf\x13\x12!\n\x1ck_EMsgGCClientVersionUpdated\x10\xe0\x13*\x9b\x02\n\x0e\x45GCMsgResponse\x12\x16\n\x12k_EGCMsgResponseOK\x10\x00\x12\x1a\n\x16k_EGCMsgResponseDenied\x10\x01\x12\x1f\n\x1bk_EGCMsgResponseServerError\x10\x02\x12\x1b\n\x17k_EGCMsgResponseTimeout\x10\x03\x12\x1b\n\x17k_EGCMsgResponseInvalid\x10\x04\x12\x1b\n\x17k_EGCMsgResponseNoMatch\x10\x05\x12 \n\x1ck_EGCMsgResponseUnknownError\x10\x06\x12\x1f\n\x1bk_EGCMsgResponseNotLoggedOn\x10\x07\x12\x1a\n\x16k_EGCMsgFailedToCreate\x10\x08*\xe9\x01\n\x0c\x45UnlockStyle\x12\x1b\n\x17k_UnlockStyle_Succeeded\x10\x00\x12\x1f\n\x1bk_UnlockStyle_Failed_PreReq\x10\x01\x12#\n\x1fk_UnlockStyle_Failed_CantAfford\x10\x02\x12#\n\x1fk_UnlockStyle_Failed_CantCommit\x10\x03\x12&\n\"k_UnlockStyle_Failed_CantLockCache\x10\x04\x12)\n%k_UnlockStyle_Failed_CantAffordAttrib\x10\x05\x42\x05H\x01\x80\x01\x00')
  ,
  dependencies=[demoparser_dot_protobufs_dot_steammessages__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_EGCITEMMSG = _descriptor.EnumDescriptor(
  name='EGCItemMsg',
  full_name='EGCItemMsg',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCBase', index=0, number=1000,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSetItemPosition', index=1, number=1001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCraft', index=2, number=1002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCraftResponse', index=3, number=1003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDelete', index=4, number=1004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCVerifyCacheSubscription', index=5, number=1005,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCNameItem', index=6, number=1006,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUnlockCrate', index=7, number=1007,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUnlockCrateResponse', index=8, number=1008,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPaintItem', index=9, number=1009,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPaintItemResponse', index=10, number=1010,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGoldenWrenchBroadcast', index=11, number=1011,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCMOTDRequest', index=12, number=1012,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCMOTDRequestResponse', index=13, number=1013,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddItemToSocket_DEPRECATED', index=14, number=1014,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddItemToSocketResponse_DEPRECATED', index=15, number=1015,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddSocketToBaseItem_DEPRECATED', index=16, number=1016,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddSocketToItem_DEPRECATED', index=17, number=1017,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddSocketToItemResponse_DEPRECATED', index=18, number=1018,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCNameBaseItem', index=19, number=1019,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCNameBaseItemResponse', index=20, number=1020,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveSocketItem_DEPRECATED', index=21, number=1021,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveSocketItemResponse_DEPRECATED', index=22, number=1022,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCustomizeItemTexture', index=23, number=1023,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCustomizeItemTextureResponse', index=24, number=1024,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUseItemRequest', index=25, number=1025,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUseItemResponse', index=26, number=1026,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGiftedItems_DEPRECATED', index=27, number=1027,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveItemName', index=28, number=1030,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveItemPaint', index=29, number=1031,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGiftWrapItem', index=30, number=1032,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGiftWrapItemResponse', index=31, number=1033,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDeliverGift', index=32, number=1034,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDeliverGiftResponseGiver', index=33, number=1035,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDeliverGiftResponseReceiver', index=34, number=1036,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUnwrapGiftRequest', index=35, number=1037,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUnwrapGiftResponse', index=36, number=1038,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSetItemStyle', index=37, number=1039,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUsedClaimCodeItem', index=38, number=1040,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSortItems', index=39, number=1041,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_RevolvingLootList_DEPRECATED', index=40, number=1042,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLookupAccount', index=41, number=1043,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLookupAccountResponse', index=42, number=1044,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLookupAccountName', index=43, number=1045,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLookupAccountNameResponse', index=44, number=1046,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUpdateItemSchema', index=45, number=1049,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveCustomTexture', index=46, number=1051,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveCustomTextureResponse', index=47, number=1052,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveMakersMark', index=48, number=1053,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveMakersMarkResponse', index=49, number=1054,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveUniqueCraftIndex', index=50, number=1055,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveUniqueCraftIndexResponse', index=51, number=1056,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSaxxyBroadcast', index=52, number=1057,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCBackpackSortFinished', index=53, number=1058,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAdjustItemEquippedState', index=54, number=1059,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCollectItem', index=55, number=1061,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemAcknowledged__DEPRECATED', index=56, number=1062,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_ReportAbuse', index=57, number=1065,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_ReportAbuseResponse', index=58, number=1066,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCNameItemNotification', index=59, number=1068,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCApplyConsumableEffects', index=60, number=1069,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCConsumableExhausted', index=61, number=1070,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCShowItemsPickedUp', index=62, number=1071,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientDisplayNotification', index=63, number=1072,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCApplyStrangePart', index=64, number=1073,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_IncrementKillCountAttribute', index=65, number=1074,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_IncrementKillCountResponse', index=66, number=1075,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCApplyPennantUpgrade', index=67, number=1076,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSetItemPositions', index=68, number=1077,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCApplyEggEssence', index=69, number=1078,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCNameEggEssenceResponse', index=70, number=1079,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPaintKitItem', index=71, number=1080,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPaintKitBaseItem', index=72, number=1081,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPaintKitItemResponse', index=73, number=1082,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGiftedItems', index=74, number=1083,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUnlockItemStyle', index=75, number=1084,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUnlockItemStyleResponse', index=76, number=1085,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCApplySticker', index=77, number=1086,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemAcknowledged', index=78, number=1087,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStatTrakSwap', index=79, number=1088,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUserTrackTimePlayedConsecutively', index=80, number=1089,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTradingBase', index=81, number=1500,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_InitiateTradeRequest', index=82, number=1501,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_InitiateTradeResponse', index=83, number=1502,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_StartSession', index=84, number=1503,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_SetItem', index=85, number=1504,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_RemoveItem', index=86, number=1505,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_UpdateTradeInfo', index=87, number=1506,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_SetReadiness', index=88, number=1507,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_ReadinessResponse', index=89, number=1508,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_SessionClosed', index=90, number=1509,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_CancelSession', index=91, number=1510,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_TradeChatMsg', index=92, number=1511,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_ConfirmOffer', index=93, number=1512,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_TradeTypingChatMsg', index=94, number=1513,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerBrowser_FavoriteServer', index=95, number=1601,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerBrowser_BlacklistServer', index=96, number=1602,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerRentalsBase', index=97, number=1700,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemPreviewCheckStatus', index=98, number=1701,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemPreviewStatusResponse', index=99, number=1702,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemPreviewRequest', index=100, number=1703,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemPreviewRequestResponse', index=101, number=1704,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemPreviewExpire', index=102, number=1705,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemPreviewExpireNotification', index=103, number=1706,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemPreviewItemBoughtNotification', index=104, number=1707,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDev_NewItemRequest', index=105, number=2001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDev_NewItemRequestResponse', index=106, number=2002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDev_PaintKitDropItem', index=107, number=2003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStoreGetUserData', index=108, number=2500,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStoreGetUserDataResponse', index=109, number=2501,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseInit_DEPRECATED', index=110, number=2502,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseInitResponse_DEPRECATED', index=111, number=2503,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseFinalize', index=112, number=2504,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseFinalizeResponse', index=113, number=2505,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseCancel', index=114, number=2506,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseCancelResponse', index=115, number=2507,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseQueryTxn', index=116, number=2508,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseQueryTxnResponse', index=117, number=2509,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseInit', index=118, number=2510,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseInitResponse', index=119, number=2511,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCBannedWordListRequest', index=120, number=2512,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCBannedWordListResponse', index=121, number=2513,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCBannedWordListBroadcast', index=122, number=2514,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCBannedWordListUpdated', index=123, number=2515,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCDirtySDOCache', index=124, number=2516,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCDirtyMultipleSDOCache', index=125, number=2517,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUpdateSQLKeyValue', index=126, number=2518,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCIsTrustedServer', index=127, number=2519,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCIsTrustedServerResponse', index=128, number=2520,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCBroadcastConsoleCommand', index=129, number=2521,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerVersionUpdated', index=130, number=2522,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCApplyAutograph', index=131, number=2523,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCWebAPIAccountChanged', index=132, number=2524,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestAnnouncements', index=133, number=2525,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestAnnouncementsResponse', index=134, number=2526,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestPassportItemGrant', index=135, number=2527,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientVersionUpdated', index=136, number=2528,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=372,
  serialized_end=5239,
)
_sym_db.RegisterEnumDescriptor(_EGCITEMMSG)

EGCItemMsg = enum_type_wrapper.EnumTypeWrapper(_EGCITEMMSG)
_EGCMSGRESPONSE = _descriptor.EnumDescriptor(
  name='EGCMsgResponse',
  full_name='EGCMsgResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseOK', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseDenied', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseServerError', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseTimeout', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseInvalid', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseNoMatch', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseUnknownError', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseNotLoggedOn', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgFailedToCreate', index=8, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5242,
  serialized_end=5525,
)
_sym_db.RegisterEnumDescriptor(_EGCMSGRESPONSE)

EGCMsgResponse = enum_type_wrapper.EnumTypeWrapper(_EGCMSGRESPONSE)
_EUNLOCKSTYLE = _descriptor.EnumDescriptor(
  name='EUnlockStyle',
  full_name='EUnlockStyle',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Succeeded', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_PreReq', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_CantAfford', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_CantCommit', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_CantLockCache', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_CantAffordAttrib', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5528,
  serialized_end=5761,
)
_sym_db.RegisterEnumDescriptor(_EUNLOCKSTYLE)

EUnlockStyle = enum_type_wrapper.EnumTypeWrapper(_EUNLOCKSTYLE)
k_EMsgGCBase = 1000
k_EMsgGCSetItemPosition = 1001
k_EMsgGCCraft = 1002
k_EMsgGCCraftResponse = 1003
k_EMsgGCDelete = 1004
k_EMsgGCVerifyCacheSubscription = 1005
k_EMsgGCNameItem = 1006
k_EMsgGCUnlockCrate = 1007
k_EMsgGCUnlockCrateResponse = 1008
k_EMsgGCPaintItem = 1009
k_EMsgGCPaintItemResponse = 1010
k_EMsgGCGoldenWrenchBroadcast = 1011
k_EMsgGCMOTDRequest = 1012
k_EMsgGCMOTDRequestResponse = 1013
k_EMsgGCAddItemToSocket_DEPRECATED = 1014
k_EMsgGCAddItemToSocketResponse_DEPRECATED = 1015
k_EMsgGCAddSocketToBaseItem_DEPRECATED = 1016
k_EMsgGCAddSocketToItem_DEPRECATED = 1017
k_EMsgGCAddSocketToItemResponse_DEPRECATED = 1018
k_EMsgGCNameBaseItem = 1019
k_EMsgGCNameBaseItemResponse = 1020
k_EMsgGCRemoveSocketItem_DEPRECATED = 1021
k_EMsgGCRemoveSocketItemResponse_DEPRECATED = 1022
k_EMsgGCCustomizeItemTexture = 1023
k_EMsgGCCustomizeItemTextureResponse = 1024
k_EMsgGCUseItemRequest = 1025
k_EMsgGCUseItemResponse = 1026
k_EMsgGCGiftedItems_DEPRECATED = 1027
k_EMsgGCRemoveItemName = 1030
k_EMsgGCRemoveItemPaint = 1031
k_EMsgGCGiftWrapItem = 1032
k_EMsgGCGiftWrapItemResponse = 1033
k_EMsgGCDeliverGift = 1034
k_EMsgGCDeliverGiftResponseGiver = 1035
k_EMsgGCDeliverGiftResponseReceiver = 1036
k_EMsgGCUnwrapGiftRequest = 1037
k_EMsgGCUnwrapGiftResponse = 1038
k_EMsgGCSetItemStyle = 1039
k_EMsgGCUsedClaimCodeItem = 1040
k_EMsgGCSortItems = 1041
k_EMsgGC_RevolvingLootList_DEPRECATED = 1042
k_EMsgGCLookupAccount = 1043
k_EMsgGCLookupAccountResponse = 1044
k_EMsgGCLookupAccountName = 1045
k_EMsgGCLookupAccountNameResponse = 1046
k_EMsgGCUpdateItemSchema = 1049
k_EMsgGCRemoveCustomTexture = 1051
k_EMsgGCRemoveCustomTextureResponse = 1052
k_EMsgGCRemoveMakersMark = 1053
k_EMsgGCRemoveMakersMarkResponse = 1054
k_EMsgGCRemoveUniqueCraftIndex = 1055
k_EMsgGCRemoveUniqueCraftIndexResponse = 1056
k_EMsgGCSaxxyBroadcast = 1057
k_EMsgGCBackpackSortFinished = 1058
k_EMsgGCAdjustItemEquippedState = 1059
k_EMsgGCCollectItem = 1061
k_EMsgGCItemAcknowledged__DEPRECATED = 1062
k_EMsgGC_ReportAbuse = 1065
k_EMsgGC_ReportAbuseResponse = 1066
k_EMsgGCNameItemNotification = 1068
k_EMsgGCApplyConsumableEffects = 1069
k_EMsgGCConsumableExhausted = 1070
k_EMsgGCShowItemsPickedUp = 1071
k_EMsgGCClientDisplayNotification = 1072
k_EMsgGCApplyStrangePart = 1073
k_EMsgGC_IncrementKillCountAttribute = 1074
k_EMsgGC_IncrementKillCountResponse = 1075
k_EMsgGCApplyPennantUpgrade = 1076
k_EMsgGCSetItemPositions = 1077
k_EMsgGCApplyEggEssence = 1078
k_EMsgGCNameEggEssenceResponse = 1079
k_EMsgGCPaintKitItem = 1080
k_EMsgGCPaintKitBaseItem = 1081
k_EMsgGCPaintKitItemResponse = 1082
k_EMsgGCGiftedItems = 1083
k_EMsgGCUnlockItemStyle = 1084
k_EMsgGCUnlockItemStyleResponse = 1085
k_EMsgGCApplySticker = 1086
k_EMsgGCItemAcknowledged = 1087
k_EMsgGCStatTrakSwap = 1088
k_EMsgGCUserTrackTimePlayedConsecutively = 1089
k_EMsgGCTradingBase = 1500
k_EMsgGCTrading_InitiateTradeRequest = 1501
k_EMsgGCTrading_InitiateTradeResponse = 1502
k_EMsgGCTrading_StartSession = 1503
k_EMsgGCTrading_SetItem = 1504
k_EMsgGCTrading_RemoveItem = 1505
k_EMsgGCTrading_UpdateTradeInfo = 1506
k_EMsgGCTrading_SetReadiness = 1507
k_EMsgGCTrading_ReadinessResponse = 1508
k_EMsgGCTrading_SessionClosed = 1509
k_EMsgGCTrading_CancelSession = 1510
k_EMsgGCTrading_TradeChatMsg = 1511
k_EMsgGCTrading_ConfirmOffer = 1512
k_EMsgGCTrading_TradeTypingChatMsg = 1513
k_EMsgGCServerBrowser_FavoriteServer = 1601
k_EMsgGCServerBrowser_BlacklistServer = 1602
k_EMsgGCServerRentalsBase = 1700
k_EMsgGCItemPreviewCheckStatus = 1701
k_EMsgGCItemPreviewStatusResponse = 1702
k_EMsgGCItemPreviewRequest = 1703
k_EMsgGCItemPreviewRequestResponse = 1704
k_EMsgGCItemPreviewExpire = 1705
k_EMsgGCItemPreviewExpireNotification = 1706
k_EMsgGCItemPreviewItemBoughtNotification = 1707
k_EMsgGCDev_NewItemRequest = 2001
k_EMsgGCDev_NewItemRequestResponse = 2002
k_EMsgGCDev_PaintKitDropItem = 2003
k_EMsgGCStoreGetUserData = 2500
k_EMsgGCStoreGetUserDataResponse = 2501
k_EMsgGCStorePurchaseInit_DEPRECATED = 2502
k_EMsgGCStorePurchaseInitResponse_DEPRECATED = 2503
k_EMsgGCStorePurchaseFinalize = 2504
k_EMsgGCStorePurchaseFinalizeResponse = 2505
k_EMsgGCStorePurchaseCancel = 2506
k_EMsgGCStorePurchaseCancelResponse = 2507
k_EMsgGCStorePurchaseQueryTxn = 2508
k_EMsgGCStorePurchaseQueryTxnResponse = 2509
k_EMsgGCStorePurchaseInit = 2510
k_EMsgGCStorePurchaseInitResponse = 2511
k_EMsgGCBannedWordListRequest = 2512
k_EMsgGCBannedWordListResponse = 2513
k_EMsgGCToGCBannedWordListBroadcast = 2514
k_EMsgGCToGCBannedWordListUpdated = 2515
k_EMsgGCToGCDirtySDOCache = 2516
k_EMsgGCToGCDirtyMultipleSDOCache = 2517
k_EMsgGCToGCUpdateSQLKeyValue = 2518
k_EMsgGCToGCIsTrustedServer = 2519
k_EMsgGCToGCIsTrustedServerResponse = 2520
k_EMsgGCToGCBroadcastConsoleCommand = 2521
k_EMsgGCServerVersionUpdated = 2522
k_EMsgGCApplyAutograph = 2523
k_EMsgGCToGCWebAPIAccountChanged = 2524
k_EMsgGCRequestAnnouncements = 2525
k_EMsgGCRequestAnnouncementsResponse = 2526
k_EMsgGCRequestPassportItemGrant = 2527
k_EMsgGCClientVersionUpdated = 2528
k_EGCMsgResponseOK = 0
k_EGCMsgResponseDenied = 1
k_EGCMsgResponseServerError = 2
k_EGCMsgResponseTimeout = 3
k_EGCMsgResponseInvalid = 4
k_EGCMsgResponseNoMatch = 5
k_EGCMsgResponseUnknownError = 6
k_EGCMsgResponseNotLoggedOn = 7
k_EGCMsgFailedToCreate = 8
k_UnlockStyle_Succeeded = 0
k_UnlockStyle_Failed_PreReq = 1
k_UnlockStyle_Failed_CantAfford = 2
k_UnlockStyle_Failed_CantCommit = 3
k_UnlockStyle_Failed_CantLockCache = 4
k_UnlockStyle_Failed_CantAffordAttrib = 5



_CMSGGCGIFTEDITEMS = _descriptor.Descriptor(
  name='CMsgGCGiftedItems',
  full_name='CMsgGCGiftedItems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CMsgGCGiftedItems.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='giftdefindex', full_name='CMsgGCGiftedItems.giftdefindex', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_gifts_possible', full_name='CMsgGCGiftedItems.max_gifts_possible', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_eligible_recipients', full_name='CMsgGCGiftedItems.num_eligible_recipients', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recipients_accountids', full_name='CMsgGCGiftedItems.recipients_accountids', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=241,
)


_CMSGAPPLYAUTOGRAPH = _descriptor.Descriptor(
  name='CMsgApplyAutograph',
  full_name='CMsgApplyAutograph',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='autograph_item_id', full_name='CMsgApplyAutograph.autograph_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_item_id', full_name='CMsgApplyAutograph.item_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=312,
)


_CMSGGCUSERTRACKTIMEPLAYEDCONSECUTIVELY = _descriptor.Descriptor(
  name='CMsgGCUserTrackTimePlayedConsecutively',
  full_name='CMsgGCUserTrackTimePlayedConsecutively',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='CMsgGCUserTrackTimePlayedConsecutively.state', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=369,
)

DESCRIPTOR.message_types_by_name['CMsgGCGiftedItems'] = _CMSGGCGIFTEDITEMS
DESCRIPTOR.message_types_by_name['CMsgApplyAutograph'] = _CMSGAPPLYAUTOGRAPH
DESCRIPTOR.message_types_by_name['CMsgGCUserTrackTimePlayedConsecutively'] = _CMSGGCUSERTRACKTIMEPLAYEDCONSECUTIVELY
DESCRIPTOR.enum_types_by_name['EGCItemMsg'] = _EGCITEMMSG
DESCRIPTOR.enum_types_by_name['EGCMsgResponse'] = _EGCMSGRESPONSE
DESCRIPTOR.enum_types_by_name['EUnlockStyle'] = _EUNLOCKSTYLE

CMsgGCGiftedItems = _reflection.GeneratedProtocolMessageType('CMsgGCGiftedItems', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCGIFTEDITEMS,
  __module__ = 'demoparser.protobufs.econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCGiftedItems)
  ))
_sym_db.RegisterMessage(CMsgGCGiftedItems)

CMsgApplyAutograph = _reflection.GeneratedProtocolMessageType('CMsgApplyAutograph', (_message.Message,), dict(
  DESCRIPTOR = _CMSGAPPLYAUTOGRAPH,
  __module__ = 'demoparser.protobufs.econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgApplyAutograph)
  ))
_sym_db.RegisterMessage(CMsgApplyAutograph)

CMsgGCUserTrackTimePlayedConsecutively = _reflection.GeneratedProtocolMessageType('CMsgGCUserTrackTimePlayedConsecutively', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCUSERTRACKTIMEPLAYEDCONSECUTIVELY,
  __module__ = 'demoparser.protobufs.econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCUserTrackTimePlayedConsecutively)
  ))
_sym_db.RegisterMessage(CMsgGCUserTrackTimePlayedConsecutively)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\200\001\000'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: demoparser/protobufs/engine_gcmessages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='demoparser/protobufs/engine_gcmessages.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n,demoparser/protobufs/engine_gcmessages.proto\x1a google/protobuf/descriptor.proto\"\xcb\x01\n\x15\x43\x45ngineGotvSyncPacket\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x13\n\x0binstance_id\x18\x02 \x01(\r\x12\x16\n\x0esignupfragment\x18\x03 \x01(\r\x12\x17\n\x0f\x63urrentfragment\x18\x04 \x01(\r\x12\x10\n\x08tickrate\x18\x05 \x01(\x02\x12\x0c\n\x04tick\x18\x06 \x01(\r\x12\x0f\n\x07rtdelay\x18\x08 \x01(\x02\x12\x0e\n\x06rcvage\x18\t \x01(\x02\x12\x19\n\x11keyframe_interval\x18\n \x01(\x02\x42\x03\x80\x01\x00')
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CENGINEGOTVSYNCPACKET = _descriptor.Descriptor(
  name='CEngineGotvSyncPacket',
  full_name='CEngineGotvSyncPacket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CEngineGotvSyncPacket.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='CEngineGotvSyncPacket.instance_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signupfragment', full_name='CEngineGotvSyncPacket.signupfragment', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currentfragment', full_name='CEngineGotvSyncPacket.currentfragment', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tickrate', full_name='CEngineGotvSyncPacket.tickrate', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tick', full_name='CEngineGotvSyncPacket.tick', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rtdelay', full_name='CEngineGotvSyncPacket.rtdelay', index=6,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rcvage', full_name='CEngineGotvSyncPacket.rcvage', index=7,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='keyframe_interval', full_name='CEngineGotvSyncPacket.keyframe_interval', index=8,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=286,
)

DESCRIPTOR.message_types_by_name['CEngineGotvSyncPacket'] = _CENGINEGOTVSYNCPACKET

CEngineGotvSyncPacket = _reflection.GeneratedProtocolMessageType('CEngineGotvSyncPacket', (_message.Message,), dict(
  DESCRIPTOR = _CENGINEGOTVSYNCPACKET,
  __module__ = 'demoparser.protobufs.engine_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CEngineGotvSyncPacket)
  ))
_sym_db.RegisterMessage(CEngineGotvSyncPacket)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\200\001\000'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: demoparser/protobufs/fatdemo.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from demoparser.protobufs import netmessages_pb2 as demoparser_dot_protobufs_dot_netmessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='demoparser/protobufs/fatdemo.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\"demoparser/protobufs/fatdemo.proto\x1a&demoparser/protobufs/netmessages.proto\"M\n\x06MLDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nval_string\x18\x02 \x01(\t\x12\x0f\n\x07val_int\x18\x03 \x01(\x05\x12\x11\n\tval_float\x18\x04 \x01(\x02\"4\n\x07MLEvent\x12\x12\n\nevent_name\x18\x01 \x01(\t\x12\x15\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x07.MLDict\"b\n\x0cMLMatchState\x12\x11\n\tgame_mode\x18\x01 \x01(\t\x12\r\n\x05phase\x18\x02 \x01(\t\x12\r\n\x05round\x18\x03 \x01(\x05\x12\x10\n\x08score_ct\x18\x04 \x01(\x05\x12\x0f\n\x07score_t\x18\x05 \x01(\x05\"W\n\x0cMLRoundState\x12\r\n\x05phase\x18\x01 \x01(\t\x12$\n\x08win_team\x18\x02 \x01(\x0e\x32\x06.ETeam:\nET_Unknown\x12\x12\n\nbomb_state\x18\x03 \x01(\t\"\xb8\x01\n\rMLWeaponState\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04type\x18\x03 \x01(\x0e\x32\x0c.EWeaponType:\tEWT_Knife\x12\x11\n\tammo_clip\x18\x04 \x01(\x05\x12\x15\n\rammo_clip_max\x18\x05 \x01(\x05\x12\x14\n\x0c\x61mmo_reserve\x18\x06 \x01(\x05\x12\r\n\x05state\x18\x07 \x01(\t\x12\x14\n\x0crecoil_index\x18\x08 \x01(\x02\"\xb3\x03\n\rMLPlayerState\x12\x12\n\naccount_id\x18\x01 \x01(\x05\x12\x0f\n\x07user_id\x18\x02 \x01(\x05\x12\x10\n\x08\x65ntindex\x18\x03 \x01(\x05\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0c\n\x04\x63lan\x18\x05 \x01(\t\x12 \n\x04team\x18\x06 \x01(\x0e\x32\x06.ETeam:\nET_Unknown\x12\x1b\n\x06\x61\x62spos\x18\x07 \x01(\x0b\x32\x0b.CMsgVector\x12\x1d\n\x08\x65yeangle\x18\x08 \x01(\x0b\x32\x0b.CMsgQAngle\x12!\n\x0c\x65yeangle_fwd\x18\t \x01(\x0b\x32\x0b.CMsgVector\x12\x0e\n\x06health\x18\n \x01(\x05\x12\r\n\x05\x61rmor\x18\x0b \x01(\x05\x12\x0f\n\x07\x66lashed\x18\x0c \x01(\x02\x12\x0e\n\x06smoked\x18\r \x01(\x02\x12\r\n\x05money\x18\x0e \x01(\x05\x12\x13\n\x0bround_kills\x18\x0f \x01(\x05\x12\x14\n\x0cround_killhs\x18\x10 \x01(\x05\x12\x0f\n\x07\x62urning\x18\x11 \x01(\x02\x12\x0e\n\x06helmet\x18\x12 \x01(\x08\x12\x12\n\ndefuse_kit\x18\x13 \x01(\x08\x12\x1f\n\x07weapons\x18\x14 \x03(\x0b\x32\x0e.MLWeaponState\"j\n\x0bMLGameState\x12\x1c\n\x05match\x18\x01 \x01(\x0b\x32\r.MLMatchState\x12\x1c\n\x05round\x18\x02 \x01(\x0b\x32\r.MLRoundState\x12\x1f\n\x07players\x18\x03 \x03(\x0b\x32\x0e.MLPlayerState\"\\\n\x0cMLDemoHeader\x12\x10\n\x08map_name\x18\x01 \x01(\t\x12\x11\n\ttick_rate\x18\x02 \x01(\x05\x12\x0f\n\x07version\x18\x03 \x01(\r\x12\x16\n\x0esteam_universe\x18\x04 \x01(\r\"S\n\x06MLTick\x12\x12\n\ntick_count\x18\x01 \x01(\x05\x12\x1b\n\x05state\x18\x02 \x01(\x0b\x32\x0c.MLGameState\x12\x18\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x08.MLEvent*\xac\x01\n\tEHitGroup\x12\x0f\n\x0b\x45HG_Generic\x10\x00\x12\x0c\n\x08\x45HG_Head\x10\x01\x12\r\n\tEHG_Chest\x10\x02\x12\x0f\n\x0b\x45HG_Stomach\x10\x03\x12\x0f\n\x0b\x45HG_LeftArm\x10\x04\x12\x10\n\x0c\x45HG_RightArm\x10\x05\x12\x0f\n\x0b\x45HG_LeftLeg\x10\x06\x12\x10\n\x0c\x45HG_RightLeg\x10\x07\x12\x0c\n\x08\x45HG_Gear\x10\x08\x12\x0c\n\x08\x45HG_Miss\x10\t*F\n\x05\x45Team\x12\x0e\n\nET_Unknown\x10\x00\x12\x10\n\x0c\x45T_Spectator\x10\x01\x12\x10\n\x0c\x45T_Terrorist\x10\x02\x12\t\n\x05\x45T_CT\x10\x03*\xe4\x01\n\x0b\x45WeaponType\x12\r\n\tEWT_Knife\x10\x00\x12\x0e\n\nEWT_Pistol\x10\x01\x12\x15\n\x11\x45WT_SubMachineGun\x10\x02\x12\r\n\tEWT_Rifle\x10\x03\x12\x0f\n\x0b\x45WT_Shotgun\x10\x04\x12\x13\n\x0f\x45WT_SniperRifle\x10\x05\x12\x12\n\x0e\x45WT_MachineGun\x10\x06\x12\n\n\x06\x45WT_C4\x10\x07\x12\x0f\n\x0b\x45WT_Grenade\x10\x08\x12\x11\n\rEWT_Equipment\x10\t\x12\x15\n\x11\x45WT_StackableItem\x10\n\x12\x0f\n\x0b\x45WT_Unknown\x10\x0b')
  ,
  dependencies=[demoparser_dot_protobufs_dot_netmessages__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_EHITGROUP = _descriptor.EnumDescriptor(
  name='EHitGroup',
  full_name='EHitGroup',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EHG_Generic', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EHG_Head', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EHG_Chest', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EHG_Stomach', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EHG_LeftArm', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EHG_RightArm', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EHG_LeftLeg', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EHG_RightLeg', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EHG_Gear', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EHG_Miss', index=9, number=9,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1313,
  serialized_end=1485,
)
_sym_db.RegisterEnumDescriptor(_EHITGROUP)

EHitGroup = enum_type_wrapper.EnumTypeWrapper(_EHITGROUP)
_ETEAM = _descriptor.EnumDescriptor(
  name='ETeam',
  full_name='ETeam',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ET_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ET_Spectator', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ET_Terrorist', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ET_CT', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1487,
  serialized_end=1557,
)
_sym_db.RegisterEnumDescriptor(_ETEAM)

ETeam = enum_type_wrapper.EnumTypeWrapper(_ETEAM)
_EWEAPONTYPE = _descriptor.EnumDescriptor(
  name='EWeaponType',
  full_name='EWeaponType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EWT_Knife', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EWT_Pistol', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EWT_SubMachineGun', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EWT_Rifle', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EWT_Shotgun', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EWT_SniperRifle', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EWT_MachineGun', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EWT_C4', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EWT_Grenade', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EWT_Equipment', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EWT_StackableItem', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EWT_Unknown', index=11, number=11,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1560,
  serialized_end=1788,
)
_sym_db.RegisterEnumDescriptor(_EWEAPONTYPE)

EWeaponType = enum_type_wrapper.EnumTypeWrapper(_EWEAPONTYPE)
EHG_Generic = 0
EHG_Head = 1
EHG_Chest = 2
EHG_Stomach = 3
EHG_LeftArm = 4
EHG_RightArm = 5
EHG_LeftLeg = 6
EHG_RightLeg = 7
EHG_Gear = 8
EHG_Miss = 9
ET_Unknown = 0
ET_Spectator = 1
ET_Terrorist = 2
ET_CT = 3
EWT_Knife = 0
EWT_Pistol = 1
EWT_SubMachineGun = 2
EWT_Rifle = 3
EWT_Shotgun = 4
EWT_SniperRifle = 5
EWT_MachineGun = 6
EWT_C4 = 7
EWT_Grenade = 8
EWT_Equipment = 9
EWT_StackableItem = 10
EWT_Unknown = 11



_MLDICT = _descriptor.Descriptor(
  name='MLDict',
  full_name='MLDict',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='MLDict.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='val_string', full_name='MLDict.val_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='val_int', full_name='MLDict.val_int', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='val_float', full_name='MLDict.val_float', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=155,
)


_MLEVENT = _descriptor.Descriptor(
  name='MLEvent',
  full_name='MLEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_name', full_name='MLEvent.event_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='MLEvent.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=209,
)


_MLMATCHSTATE = _descriptor.Descriptor(
  name='MLMatchState',
  full_name='MLMatchState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='MLMatchState.game_mode', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='phase', full_name='MLMatchState.phase', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='round', full_name='MLMatchState.round', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score_ct', full_name='MLMatchState.score_ct', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score_t', full_name='MLMatchState.score_t', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=211,
  serialized_end=309,
)


_MLROUNDSTATE = _descriptor.Descriptor(
  name='MLRoundState',
  full_name='MLRoundState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='phase', full_name='MLRoundState.phase', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='win_team', full_name='MLRoundState.win_team', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bomb_state', full_name='MLRoundState.bomb_state', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=311,
  serialized_end=398,
)


_MLWEAPONSTATE = _descriptor.Descriptor(
  name='MLWeaponState',
  full_name='MLWeaponState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='MLWeaponState.index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='MLWeaponState.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='MLWeaponState.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ammo_clip', full_name='MLWeaponState.ammo_clip', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ammo_clip_max', full_name='MLWeaponState.ammo_clip_max', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ammo_reserve', full_name='MLWeaponState.ammo_reserve', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='MLWeaponState.state', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recoil_index', full_name='MLWeaponState.recoil_index', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=585,
)


_MLPLAYERSTATE = _descriptor.Descriptor(
  name='MLPlayerState',
  full_name='MLPlayerState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='MLPlayerState.account_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='MLPlayerState.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='entindex', full_name='MLPlayerState.entindex', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='MLPlayerState.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clan', full_name='MLPlayerState.clan', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team', full_name='MLPlayerState.team', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='abspos', full_name='MLPlayerState.abspos', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eyeangle', full_name='MLPlayerState.eyeangle', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eyeangle_fwd', full_name='MLPlayerState.eyeangle_fwd', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='health', full_name='MLPlayerState.health', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='armor', full_name='MLPlayerState.armor', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='flashed', full_name='MLPlayerState.flashed', index=11,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='smoked', full_name='MLPlayerState.smoked', index=12,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='money', full_name='MLPlayerState.money', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='round_kills', full_name='MLPlayerState.round_kills', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='round_killhs', full_name='MLPlayerState.round_killhs', index=15,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='burning', full_name='MLPlayerState.burning', index=16,
      number=17, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='helmet', full_name='MLPlayerState.helmet', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='defuse_kit', full_name='MLPlayerState.defuse_kit', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weapons', full_name='MLPlayerState.weapons', index=19,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=588,
  serialized_end=1023,
)


_MLGAMESTATE = _descriptor.Descriptor(
  name='MLGameState',
  full_name='MLGameState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match', full_name='MLGameState.match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='round', full_name='MLGameState.round', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players', full_name='MLGameState.players', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1025,
  serialized_end=1131,
)


_MLDEMOHEADER = _descriptor.Descriptor(
  name='MLDemoHeader',
  full_name='MLDemoHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_name', full_name='MLDemoHeader.map_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tick_rate', full_name='MLDemoHeader.tick_rate', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='MLDemoHeader.version', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steam_universe', full_name='MLDemoHeader.steam_universe', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1133,
  serialized_end=1225,
)


_MLTICK = _descriptor.Descriptor(
  name='MLTick',
  full_name='MLTick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_count', full_name='MLTick.tick_count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='MLTick.state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='events', full_name='MLTick.events', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1227,
  serialized_end=1310,
)

_MLEVENT.fields_by_name['data'].message_type = _MLDICT
_MLROUNDSTATE.fields_by_name['win_team'].enum_type = _ETEAM
_MLWEAPONSTATE.fields_by_name['type'].enum_type = _EWEAPONTYPE
_MLPLAYERSTATE.fields_by_name['team'].enum_type = _ETEAM
_MLPLAYERSTATE.fields_by_name['abspos'].message_type = demoparser_dot_protobufs_dot_netmessages__pb2._CMSGVECTOR
_MLPLAYERSTATE.fields_by_name['eyeangle'].message_type = demoparser_dot_protobufs_dot_netmessages__pb2._CMSGQANGLE
_MLPLAYERSTATE.fields_by_name['eyeangle_fwd'].message_type = demoparser_dot_protobufs_dot_netmessages__pb2._CMSGVECTOR
_MLPLAYERSTATE.fields_by_name['weapons'].message_type = _MLWEAPONSTATE
_MLGAMESTATE.fields_by_name['match'].message_type = _MLMATCHSTATE
_MLGAMESTATE.fields_by_name['round'].message_type = _MLROUNDSTATE
_MLGAMESTATE.fields_by_name['players'].message_type = _MLPLAYERSTATE
_MLTICK.fields_by_name['state'].message_type = _MLGAMESTATE
_MLTICK.fields_by_name['events'].message_type = _MLEVENT
DESCRIPTOR.message_types_by_name['MLDict'] = _MLDICT
DESCRIPTOR.message_types_by_name['MLEvent'] = _MLEVENT
DESCRIPTOR.message_types_by_name['MLMatchState'] = _MLMATCHSTATE
DESCRIPTOR.message_types_by_name['MLRoundState'] = _MLROUNDSTATE
DESCRIPTOR.message_types_by_name['MLWeaponState'] = _MLWEAPONSTATE
DESCRIPTOR.message_types_by_name['MLPlayerState'] = _MLPLAYERSTATE
DESCRIPTOR.message_types_by_name['MLGameState'] = _MLGAMESTATE
DESCRIPTOR.message_types_by_name['MLDemoHeader'] = _MLDEMOHEADER
DESCRIPTOR.message_types_by_name['MLTick'] = _MLTICK
DESCRIPTOR.enum_types_by_name['EHitGroup'] = _EHITGROUP
DESCRIPTOR.enum_types_by_name['ETeam'] = _ETEAM
DESCRIPTOR.enum_types_by_name['EWeaponType'] = _EWEAPONTYPE

MLDict = _reflection.GeneratedProtocolMessageType('MLDict', (_message.Message,), dict(
  DESCRIPTOR = _MLDICT,
  __module__ = 'demoparser.protobufs.fatdemo_pb2'
  # @@protoc_insertion_point(class_scope:MLDict)
  ))
_sym_db.RegisterMessage(MLDict)

MLEvent = _reflection.GeneratedProtocolMessageType('MLEvent', (_message.Message,), dict(
  DESCRIPTOR = _MLEVENT,
  __module__ = 'demoparser.protobufs.fatdemo_pb2'
  # @@protoc_insertion_point(class_scope:MLEvent)
  ))
_sym_db.RegisterMessage(MLEvent)

MLMatchState = _reflection.GeneratedProtocolMessageType('MLMatchState', (_message.Message,), dict(
  DESCRIPTOR = _MLMATCHSTATE,
  __module__ = 'demoparser.protobufs.fatdemo_pb2'
  # @@protoc_insertion_point(class_scope:MLMatchState)
  ))
_sym_db.RegisterMessage(MLMatchState)

MLRoundState = _reflection.GeneratedProtocolMessageType('MLRoundState', (_message.Message,), dict(
  DESCRIPTOR = _MLROUNDSTATE,
  __module__ = 'demoparser.protobufs.fatdemo_pb2'
  # @@protoc_insertion_point(class_scope:MLRoundState)
  ))
_sym_db.RegisterMessage(MLRoundState)

MLWeaponState = _reflection.GeneratedProtocolMessageType('MLWeaponState', (_message.Message,), dict(
  DESCRIPTOR = _MLWEAPONSTATE,
  __module__ = 'demoparser.protobufs.fatdemo_pb2'
  # @@protoc_insertion_point(class_scope:MLWeaponState)
  ))
_sym_db.RegisterMessage(MLWeaponState)

MLPlayerState = _reflection.GeneratedProtocolMessageType('MLPlayerState', (_message.Message,), dict(
  DESCRIPTOR = _MLPLAYERSTATE,
  __module__ = 'demoparser.protobufs.fatdemo_pb2'
  # @@protoc_insertion_point(class_scope:MLPlayerState)
  ))
_sym_db.RegisterMessage(MLPlayerState)

MLGameState = _reflection.GeneratedProtocolMessageType('MLGameState', (_message.Message,), dict(
  DESCRIPTOR = _MLGAMESTATE,
  __module__ = 'demoparser.protobufs.fatdemo_pb2'
  # @@protoc_insertion_point(class_scope:MLGameState)
  ))
_sym_db.RegisterMessage(MLGameState)

MLDemoHeader = _reflection.GeneratedProtocolMessageType('MLDemoHeader', (_message.Message,), dict(
  DESCRIPTOR = _MLDEMOHEADER,
  __module__ = 'demoparser.protobufs.fatdemo_pb2'
  # @@protoc_insertion_point(class_scope:MLDemoHeader)
  ))
_sym_db.RegisterMessage(MLDemoHeader)

MLTick = _reflection.GeneratedProtocolMessageType('MLTick', (_message.Message,), dict(
  DESCRIPTOR = _MLTICK,
  __module__ = 'demoparser.protobufs.fatdemo_pb2'
  # @@protoc_insertion_point(class_scope:MLTick)
  ))
_sym_db.RegisterMessage(MLTick)


# @@protoc_insertion_point(module_scope)



import inspect
from demoparser.entities import BaseEntity


class Team(BaseEntity):

    def __init__(self, parser, index, class_id, serial, props):
        self.parser = parser
        self.index = index
        self.class_id = class_id
        self.serial = serial
        self.props = props

    @property
    def name(self):
        """Team name. Either 'T' or 'CT'."""
        return self.get_prop('DT_Team', 'm_szTeamname')

    @property
    def clan(self):
        """Clan name."""
        return self.get_prop('DT_Team', 'm_szClanTeamname')

    @property
    def score(self):
        """Final team score."""
        return self.get_prop('DT_Team', 'm_scoreTotal')

    @property
    def score_first_half(self):
        """Score for first half of match."""
        return self.get_prop('DT_Team', 'm_scoreFirstHalf')

    @property
    def score_second_half(self):
        """Score for second half of match."""
        return self.get_prop('DT_Team', 'm_scoreSecondHalf')

    def properties(self):
        result = {
            'index': self.index,
            'class_id': self.class_id,
            'serial': self.serial,
        }

        for name, value in inspect.getmembers(self):
            prop_attr = getattr(self.__class__, name, None)
            if inspect.isdatadescriptor(prop_attr):
                attr = getattr(self, name, None)
                if not isinstance(attr, BaseEntity):
                    result[name] = value

        return result
